pub struct TempPath { /* fields omitted */ }
A simple wrapper for creating a temporary directory that is automatically deleted when it’s
dropped. Used in lieu of tempfile due to the large number of dependencies.
Create new, uninitialized temporary path in the system temp directory.
Create new, uninitialized temporary path in the specified directory.
Return the underlying path to this temporary directory.
Formats the value using the given formatter. Read more
Returns the “default value” for a type. Read more
Executes the destructor for this type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,